@@ -1,4 +1,4 @@
-__version__ = '1.0.9'
+__version__ = '1.0.10'
 __author__ = 'arnold'
 
 import json
@@ -82,7 +82,7 @@ class TerraformQueryExtension(Extension):
         # Getting the current state version outputs for the workspace.
         TFC_URL = 'https://app.terraform.io/'
         BASE_URL = urljoin(TFC_URL, "/api/v2")
-        WORKSPACE_PATH = f'/organizations/{org_name}/workspaces/{workspace_name}'
+        WORKSPACE_PATH = "/organizations/{org_name}/workspaces/{workspace_name}"
         # workspace_url = f'{BASE_URL}/organizations/{org_name}/workspaces/{workspace_name}'
         workspace_url = urljoin(BASE_URL, WORKSPACE_PATH)
         s = requests.Session()
@@ -94,7 +94,7 @@ class TerraformQueryExtension(Extension):
             raise SystemExit(err)
         search_listed_ws = resp.json()
         ws_id = search_listed_ws['data']['id']
-        state_output_path = f'/workspaces/{ws_id}/current-state-version-outputs'
+        state_output_path = "/workspaces/{ws_id}/current-state-version-outputs"
         state_output_url = urljoin(BASE_URL, state_output_path)
         try:
             resp = s.get(state_output_url)
